#!/bin/bash
#
# An entrypoint script for RTFS to allow custom setup before server starts
#
: ${SERVICE_NAME:=federation}
: ${JF_PRODUCT_HOME:=/opt/jfrog/artifactory}
: ${ARTIFACTORY_BOOTSTRAP:=/artifactory_bootstrap}
: ${BOOTSTRAP:=/bootstrap}

JF_RTFS_PID=${JF_PRODUCT_HOME}/var/work/run/${SERVICE_NAME}.pid

copyArtifactoryBootstrapFiles () {
    if [[ -d "${ARTIFACTORY_BOOTSTRAP}" ]]; then
        logger "Copying RTFS bootstrap files"
        copyFilesNoOverwrite "${ARTIFACTORY_BOOTSTRAP}" "${JF_PRODUCT_HOME}/var/etc/${SERVICE_NAME}"
    fi
}

copyBootstrapFiles () {
    if [[ -d "${BOOTSTRAP}" ]]; then
        logger "Copying bootstrap files"
        copyFilesNoOverwrite "${BOOTSTRAP}" "${JF_PRODUCT_HOME}/var/etc"
    fi
}

terminate () {
    echo -e "\nTerminating RTFS"
    "${JF_PRODUCT_HOME}"/app/"${SERVICE_NAME}"/bin/rtfs.sh stop
}

errorExit () {
  echo; echo "ERROR: ${1}"; echo
  exit 1
}

# Catch Ctrl+C and other termination signals to try graceful shutdown
trap terminate SIGINT SIGTERM SIGHUP

logger "Preparing to run RTFS in Docker"
logger "Running as $(id)"

exec "${JF_PRODUCT_HOME}"/app/"${SERVICE_NAME}"/bin/rtfs.sh &
rtfs_pid=$!

if [ -n "$JF_RTFS_PID" ];
then
    mkdir -p "$(dirname "$JF_RTFS_PID")" || \
    errorExit "Could not create dir for $JF_RTFS_PID";
fi

echo "${rtfs_pid}" > ${JF_RTFS_PID}

wait ${rtfs_pid}